﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;

namespace WindowsApplication1
{
    public partial class WawaToolStrip : ToolStrip
    {
        protected ToolStripProfessionalRenderer _pr;

        public WawaToolStrip()
        {
            // Check Dock
            Dock = DockStyle.Fill;
            GripStyle = ToolStripGripStyle.Hidden;
            Margin = new Padding(0);
            CanOverflow = false;
            AutoSize = false;
            LayoutStyle = ToolStripLayoutStyle.VerticalStackWithOverflow; //垂直排列按钮

            SetRenderer();
        }

        private void SetRenderer()
        {
            if ((Renderer is ToolStripProfessionalRenderer) && (Renderer != _pr))
            {
                if (_pr == null)
                {
                    _pr = new ToolStripProfessionalRenderer();
                    _pr.RoundedEdges = false;
                    //重绘ToolStrip的背景颜色
                    _pr.RenderToolStripBackground += StackStrip_RenderToolStripBackground;
                    OnSetRenderer(_pr);
                }
                Renderer = _pr;
            }
        }

        private void StackStrip_RenderToolStripBackground(object sender, ToolStripRenderEventArgs e)
        {
            
            if (_pr != null)
            {
                // Setup colors from the provided renderer
                Color start = _pr.ColorTable.ToolStripGradientMiddle;
                Color end = _pr.ColorTable.ToolStripGradientEnd;

                // Size to paint
                Rectangle bounds = new Rectangle(Point.Empty, e.ToolStrip.Size);

                // Make sure we need to do work
                if ((bounds.Width > 0) && (bounds.Height > 0))
                {
                    using (Brush b = new LinearGradientBrush(bounds, start, end, LinearGradientMode.Vertical))
                    {
                        e.Graphics.FillRectangle(b, bounds);
                    }
                }

                // Draw border
                //e.Graphics.DrawRectangle(SystemPens.ControlDarkDark, bounds);
                e.Graphics.DrawLine(SystemPens.ControlDarkDark, bounds.X, bounds.Y, bounds.Width - 1, bounds.Y);
                e.Graphics.DrawLine(SystemPens.ControlDarkDark, bounds.X, bounds.Y, bounds.X, bounds.Height - 1);
                e.Graphics.DrawLine(SystemPens.ControlDarkDark, bounds.X + bounds.Width - 1, bounds.Y,
                                    bounds.X + bounds.Width - 1, bounds.Height - 1);
            }
        }
        protected virtual void OnSetRenderer(ToolStripProfessionalRenderer pr)
        {
            pr.RenderButtonBackground += _pr_RenderItemBackground;
        }

        private void _pr_RenderItemBackground(object sender, ToolStripItemRenderEventArgs e)
        {
            Graphics g = e.Graphics;
            Rectangle bounds = new Rectangle(Point.Empty, e.Item.Size);

            Color gradientBegin = Color.White;
            Color gradientEnd = Color.FromArgb(198, 194, 188);

            ToolStripButton button = e.Item as ToolStripButton;
            if (button.Pressed || button.Checked)
            {
                gradientBegin = _pr.ColorTable.ButtonPressedGradientBegin;
                gradientEnd = _pr.ColorTable.ButtonPressedGradientEnd;
            }
            else if (button.Selected)
            {
                gradientBegin = _pr.ColorTable.ButtonSelectedGradientBegin;
                gradientEnd = _pr.ColorTable.ButtonSelectedGradientEnd;
            }

            // Draw Button Background
            using (Brush b = new LinearGradientBrush(bounds, gradientBegin, gradientEnd, LinearGradientMode.Vertical))
            {
                g.FillRectangle(b, bounds);
            }

            // Draw Outilne
            e.Graphics.DrawRectangle(SystemPens.ControlDarkDark, bounds);
        }


        protected override void OnRendererChanged(EventArgs e)
        {
            base.OnRendererChanged(e);

            // Work around bug with setting renderer in the constructor
            SetRenderer();
        }




    }
}